import { promises as fs, existsSync } from "fs"
import { webcrypto, createHmac } from "crypto"

import type { IAdapter } from "./index"

/**
 * Default Node.js adapter. This can be used while using `opvault.js`
 * in a Node.js environment.
 */
export const adapter: IAdapter = {
  fs: {
    readFile: path => fs.readFile(path, "utf-8"),
    readBuffer: path => fs.readFile(path),
    writeFile: fs.writeFile,
    readdir: fs.readdir,
    isDirectory: async path => fs.stat(path).then(x => x.isDirectory()),
    exists: async path => existsSync(path),
  },
  subtle: (webcrypto as any).subtle,
  hmacSHA256: (key, data) => createHmac("sha256", key).update(data).digest(),
}
